==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/df/d2f/object__cmd_8cpp.js <==
var object__cmd_8cpp =
[
    [ "GetCompanyHQSize", "df/d2f/object__cmd_8cpp.html#a9b6eb88ac391ddca74b2ce2d6f822346", null ],
    [ "IncreaseCompanyHQSize", "df/d2f/object__cmd_8cpp.html#a49dc6b94750866039264f2c03d36aba1", null ],
    [ "AddAcceptedCargo_Object", "df/d2f/object__cmd_8cpp.html#aa2d7363f4db3bca5fe83a5deaef6afa9", null ],
    [ "AnimateTile_Object", "df/d2f/object__cmd_8cpp.html#a28be15517bc85eccee0083fc44cadda0", null ],
    [ "BuildObject", "df/d2f/object__cmd_8cpp.html#ada3b8ebf0c3b3a90905ceb73b26ee6ec", null ],
    [ "ChangeTileOwner_Object", "df/d2f/object__cmd_8cpp.html#a7703d7f3232aba1a2da1d28efcbb8584", null ],
    [ "CheckBuildableTile", "df/d2f/object__cmd_8cpp.html#a010f2bd10db86e23047da0cd48e690fe", null ],
    [ "ClearTile_Object", "df/d2f/object__cmd_8cpp.html#a69365b2ccc40e00c6d94470866022553", null ],
    [ "ClickTile_Object", "df/d2f/object__cmd_8cpp.html#a08d55bea2fc9cb7186ed6e0524aebcc0", null ],
    [ "CmdBuildObject", "df/d2f/object__cmd_8cpp.html#ac79de3c5870b2fa7f9e9eb50f82aef6c", null ],
    [ "DrawTile_Object", "df/d2f/object__cmd_8cpp.html#a0099ef706260845fe53131dc53c2c72d", null ],
    [ "FindClearedObject", "df/d2f/object__cmd_8cpp.html#ab83cb00984cda897e60488e675bf2d8a", null ],
    [ "GenerateObjects", "df/d2f/object__cmd_8cpp.html#a3c875381fb2520359f69e97ad0b321c7", null ],
    [ "GetFoundation_Object", "df/d2f/object__cmd_8cpp.html#adea2da0f330bffc7bef29a47790e31d8", null ],
    [ "GetObjectType", "df/d2f/object__cmd_8cpp.html#adc0a8358ed0f0542c4d831992039fab4", null ],
    [ "GetSlopePixelZ_Object", "df/d2f/object__cmd_8cpp.html#a210b8108c50e7891dc750de3009a9067", null ],
    [ "GetTileDesc_Object", "df/d2f/object__cmd_8cpp.html#a5b59c7bb8e2eef4c4f3e136a991361ee", null ],
    [ "GetTileTrackStatus_Object", "df/d2f/object__cmd_8cpp.html#a1e16f4774c0d19d8cbaf14d89cd0f6cc", null ],
    [ "HasTransmitter", "df/d2f/object__cmd_8cpp.html#ab1f92b6b76a21de816630799c8e0c31d", null ],
    [ "IncreaseAnimationStage", "df/d2f/object__cmd_8cpp.html#a9cd5ec5175bca6c0ee88e958929fe3e8", null ],
    [ "InitializeObjects", "df/d2f/object__cmd_8cpp.html#a3df4bc59768117eaf6fe1e7638074f95", null ],
    [ "ReallyClearObjectTile", "df/d2f/object__cmd_8cpp.html#a257afc4775bb4819ff1d855614498436", null ],
    [ "TerraformTile_Object", "df/d2f/object__cmd_8cpp.html#a5f368cebaca162fde61ddab90a64ae54", null ],
    [ "TileLoop_Object", "df/d2f/object__cmd_8cpp.html#aff4a2cb10d2c56994e41e663213807ca", null ],
    [ "TryBuildLightHouse", "df/d2f/object__cmd_8cpp.html#a8e943217f9da2bbe3a3902c9b8a6cfa3", null ],
    [ "TryBuildTransmitter", "df/d2f/object__cmd_8cpp.html#a841b37186522e0c28aa478ec85fb4432", null ],
    [ "UpdateCompanyHQ", "df/d2f/object__cmd_8cpp.html#ad3fcf7af1c04d7cfe7968cab3380bc9e", null ],
    [ "UpdateObjectColours", "df/d2f/object__cmd_8cpp.html#a0576c1bb054c65e8d2e1ad320ff09bde", null ],
    [ "_cleared_object_areas", "df/d2f/object__cmd_8cpp.html#ac58839ce4440b0c1adf23b4438c34dba", null ],
    [ "_object_pool", "df/d2f/object__cmd_8cpp.html#a1eaf7528cdf1fe6b77d3dd3f5c46e5fa", null ],
    [ "_tile_type_object_procs", "df/d2f/object__cmd_8cpp.html#a9095a7ce0b24cdf2b4ffb1d3ca884846", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/df/d2f/object__cmd_8cpp.js <==
var object__cmd_8cpp =
[
    [ "GetCompanyHQSize", "df/d2f/object__cmd_8cpp.html#a9b6eb88ac391ddca74b2ce2d6f822346", null ],
    [ "IncreaseCompanyHQSize", "df/d2f/object__cmd_8cpp.html#a49dc6b94750866039264f2c03d36aba1", null ],
    [ "AddAcceptedCargo_Object", "df/d2f/object__cmd_8cpp.html#aa2d7363f4db3bca5fe83a5deaef6afa9", null ],
    [ "AddProducedCargo_Object", "df/d2f/object__cmd_8cpp.html#a38b1713a731c53ff71c7ec3de19c101e", null ],
    [ "AnimateTile_Object", "df/d2f/object__cmd_8cpp.html#a28be15517bc85eccee0083fc44cadda0", null ],
    [ "BuildObject", "df/d2f/object__cmd_8cpp.html#ada3b8ebf0c3b3a90905ceb73b26ee6ec", null ],
    [ "ChangeTileOwner_Object", "df/d2f/object__cmd_8cpp.html#a7703d7f3232aba1a2da1d28efcbb8584", null ],
    [ "CheckBuildableTile", "df/d2f/object__cmd_8cpp.html#a010f2bd10db86e23047da0cd48e690fe", null ],
    [ "ClearTile_Object", "df/d2f/object__cmd_8cpp.html#a69365b2ccc40e00c6d94470866022553", null ],
    [ "ClickTile_Object", "df/d2f/object__cmd_8cpp.html#a08d55bea2fc9cb7186ed6e0524aebcc0", null ],
    [ "CmdBuildObject", "df/d2f/object__cmd_8cpp.html#ac79de3c5870b2fa7f9e9eb50f82aef6c", null ],
    [ "DrawTile_Object", "df/d2f/object__cmd_8cpp.html#a0099ef706260845fe53131dc53c2c72d", null ],
    [ "FindClearedObject", "df/d2f/object__cmd_8cpp.html#ab83cb00984cda897e60488e675bf2d8a", null ],
    [ "GenerateObjects", "df/d2f/object__cmd_8cpp.html#a3c875381fb2520359f69e97ad0b321c7", null ],
    [ "GetFoundation_Object", "df/d2f/object__cmd_8cpp.html#adea2da0f330bffc7bef29a47790e31d8", null ],
    [ "GetObjectType", "df/d2f/object__cmd_8cpp.html#adc0a8358ed0f0542c4d831992039fab4", null ],
    [ "GetSlopePixelZ_Object", "df/d2f/object__cmd_8cpp.html#a210b8108c50e7891dc750de3009a9067", null ],
    [ "GetTileDesc_Object", "df/d2f/object__cmd_8cpp.html#a5b59c7bb8e2eef4c4f3e136a991361ee", null ],
    [ "GetTileTrackStatus_Object", "df/d2f/object__cmd_8cpp.html#a1e16f4774c0d19d8cbaf14d89cd0f6cc", null ],
    [ "HasTransmitter", "df/d2f/object__cmd_8cpp.html#ab1f92b6b76a21de816630799c8e0c31d", null ],
    [ "IncreaseAnimationStage", "df/d2f/object__cmd_8cpp.html#a9cd5ec5175bca6c0ee88e958929fe3e8", null ],
    [ "InitializeObjects", "df/d2f/object__cmd_8cpp.html#a3df4bc59768117eaf6fe1e7638074f95", null ],
    [ "ReallyClearObjectTile", "df/d2f/object__cmd_8cpp.html#a257afc4775bb4819ff1d855614498436", null ],
    [ "TerraformTile_Object", "df/d2f/object__cmd_8cpp.html#a5f368cebaca162fde61ddab90a64ae54", null ],
    [ "TileLoop_Object", "df/d2f/object__cmd_8cpp.html#aff4a2cb10d2c56994e41e663213807ca", null ],
    [ "TryBuildLightHouse", "df/d2f/object__cmd_8cpp.html#a8e943217f9da2bbe3a3902c9b8a6cfa3", null ],
    [ "TryBuildTransmitter", "df/d2f/object__cmd_8cpp.html#a841b37186522e0c28aa478ec85fb4432", null ],
    [ "UpdateCompanyHQ", "df/d2f/object__cmd_8cpp.html#ad3fcf7af1c04d7cfe7968cab3380bc9e", null ],
    [ "UpdateObjectColours", "df/d2f/object__cmd_8cpp.html#a0576c1bb054c65e8d2e1ad320ff09bde", null ],
    [ "_cleared_object_areas", "df/d2f/object__cmd_8cpp.html#a4396f681f6b1ce4c22e1ccabc054223b", null ],
    [ "_object_pool", "df/d2f/object__cmd_8cpp.html#a1eaf7528cdf1fe6b77d3dd3f5c46e5fa", null ],
    [ "_tile_type_object_procs", "df/d2f/object__cmd_8cpp.html#a9095a7ce0b24cdf2b4ffb1d3ca884846", null ]
];
